# pytiva
Python Tools for Investigating and Visualizing Activity (PyTIVA) within anesthetic records

A toolkit for extracting, parsing, and processing anesthesia records and making sense of the activity contained therein.

See the included tutorial.ipynb for examples and how to get started.
